==> xl-react-components-0.16.62.tgz: package/app/xl-react-dip/xl-react-dip-map-string-string/xl-react-dip-map-string-string-component.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import debounce from 'debounce';
import {localeMessages} from '../../services/locale-service';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactWidgetAlertMessage} from '../../xl-react-widget/xl-react-widget-alert-message/xl-react-widget-alert-message'; // eslint-disable-line max-len
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';
import {ScrollableContainer} from './scrollable-container';
import {TopPanelComponent} from './top-panel';
import {getMapKeyInputType} from './xl-react-dip-map-string-string-constants';
import {COLUMNS} from './map-table-utils';

import './xl-react-dip-map-string-string.less';

export const INPUT_DEBOUNCE_TIME = 300;

export class XlReactDipMapStringStringComponent extends Component {
    static propTypes = {
        assignRef: PropTypes.func,
        assignTableRef: PropTypes.func,
        assignTableWrapperRef: PropTypes.func,
        autoHide: PropTypes.bool,
        cellState: PropTypes.shape({
            column: PropTypes.oneOf([COLUMNS.key, COLUMNS.value]),
            row: PropTypes.number,
            value: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
        }),
        description: PropTypes.string,
        disabled: PropTypes.bool,
        duplicateKey: PropTypes.string,
        emptyKey: PropTypes.bool,
        encrypted: PropTypes.bool,
        handleAddRow: PropTypes.func,
        handleCloseButton: PropTypes.func,
        handleNewKeyBlur: PropTypes.func,
        handleNewKeyChange: PropTypes.func,
        handleNewKeyFocus: PropTypes.func,
        handleNewValueBlur: PropTypes.func,
        handleNewValueFocus: PropTypes.func,
        handleNewValueKeyDown: PropTypes.func,
        handleSortChange: PropTypes.func,
        label: PropTypes.string,
        message: xlMessageTypeProp,
        model: PropTypes.object,
        modelKeys: PropTypes.array,
        newKey: PropTypes.string,
        newValue: PropTypes.string,
        onCleaningSearchWord: PropTypes.func,
        onKeyBlur: PropTypes.func,
        onRemoveKey: PropTypes.func,
        onSearchChanged: PropTypes.func,
        onValidityChange: PropTypes.func,
        onValueChange: PropTypes.func,
        pristine: PropTypes.bool,
        required: PropTypes.bool,
        searchWord: PropTypes.string,
        showNewKeyValueRow: PropTypes.bool,
        sorting: PropTypes.object,
        updateCellState: PropTypes.func,
        valid: PropTypes.bool
    };

    static defaultProps = {encrypted: false};

    state = {typedWord: this.props.searchWord};

    componentWillReceiveProps(nextProps) {
        this.setState({typedWord: nextProps.searchWord});
    }

    onSearchChanged = (event) => {
        const newValue = event.target.value;
        this.setState({typedWord: newValue});
        this.debounceSearchChanged(newValue);
    };

    debounceSearchChanged = debounce(this.props.onSearchChanged, INPUT_DEBOUNCE_TIME);

    render() {
        const {
            autoHide,
            assignTableRef,
            assignTableWrapperRef,
            assignRef,
            description,
            disabled,
            duplicateKey,
            emptyKey,
            encrypted,
            cellState,
            handleAddRow,
            handleCloseButton,
            handleNewKeyBlur,
            handleNewKeyChange,
            handleNewKeyFocus,
            handleNewValueBlur,
            handleNewValueFocus,
            handleNewValueKeyDown,
            handleSortChange,
            label,
            message,
            model,
            modelKeys,
            newKey,
            newValue,
            onCleaningSearchWord,
            onKeyBlur,
            onRemoveKey,
            onValueChange,
            pristine,
            required,
            searchWord,
            showNewKeyValueRow,
            updateCellState,
            valid,
            sorting
        } = this.props;

        const {typedWord} = this.state;

        const inputType = getMapKeyInputType(encrypted);

        const displayKeyError = <XlReactWidgetAlertMessage
            hide={R.isNil(duplicateKey) && R.isNil(emptyKey)}
            internalState="error">
            {duplicateKey ? localeMessages.keyAlreadyInUse(duplicateKey) : localeMessages.emptyKeyErrorMessage}
        </XlReactWidgetAlertMessage>;

        const topPanel = () => <TopPanelComponent
            disabled={disabled}
            handleAddRow={handleAddRow}
            handleCleaningSearchWord={onCleaningSearchWord}
            handleSearchChanged={this.onSearchChanged}
            searchWord={typedWord}
        />;

        const hideContainer = () => autoHide !== false && R.isEmpty(modelKeys) && !showNewKeyValueRow;
        const container = () => !hideContainer() && <ScrollableContainer
            assignRef={assignRef}
            assignTableRef={assignTableRef}
            assignTableWrapperRef={assignTableWrapperRef}
            cellState={cellState}
            disabled={disabled}
            encrypted={encrypted}
            handleCloseButton={handleCloseButton}
            handleKeyBlur={onKeyBlur}
            handleNewKeyBlur={handleNewKeyBlur}
            handleNewKeyChange={handleNewKeyChange}
            handleNewKeyFocus={handleNewKeyFocus}
            handleNewValueBlur={handleNewValueBlur}
            handleNewValueFocus={handleNewValueFocus}
            handleNewValueKeyDown={handleNewValueKeyDown}
            handleRemoveKey={onRemoveKey}
            handleSortChange={handleSortChange}
            handleValueChange={onValueChange}
            hasKeyError={Boolean(duplicateKey || emptyKey)}
            inputType={inputType}
            message={message}
            model={model}
            modelKeys={modelKeys}
            newKey={newKey}
            newValue={newValue}
            pristine={pristine}
            searchWord={searchWord}
            showNewKeyValueRow={showNewKeyValueRow}
            sorting={sorting}
            updateCellState={updateCellState}
            valid={valid}
        />;

        const controlProps = {
            controlClass: 'xl-map-string-string',
            customControlClasses: validationMessageClasses(valid, message),
            description,
            disabled,
            label,
            message,
            required
        };

        return <XlReactFormItemControl {...controlProps}>
            {topPanel()}
            {displayKeyError}
            {container()}
        </XlReactFormItemControl>;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-dip/xl-react-dip-map-string-string/xl-react-dip-map-string-string-component.js <==
import React, {Component} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import debounce from 'debounce';
import {localeMessages} from '../../services/locale-service';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactWidgetAlertMessage} from '../../xl-react-widget/xl-react-widget-alert-message/xl-react-widget-alert-message'; // eslint-disable-line max-len
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';
import {ScrollableContainer} from './scrollable-container';
import {TopPanelComponent} from './top-panel';
import {getMapKeyInputType} from './xl-react-dip-map-string-string-constants';
import {COLUMNS} from './map-table-utils';

import './xl-react-dip-map-string-string.less';

export const INPUT_DEBOUNCE_TIME = 300;

export class XlReactDipMapStringStringComponent extends Component {
    static propTypes = {
        assignRef: PropTypes.func,
        assignTableRef: PropTypes.func,
        assignTableWrapperRef: PropTypes.func,
        autoHide: PropTypes.bool,
        cellState: PropTypes.shape({
            column: PropTypes.oneOf([COLUMNS.key, COLUMNS.value]),
            row: PropTypes.number,
            value: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
        }),
        description: PropTypes.string,
        disabled: PropTypes.bool,
        duplicateKey: PropTypes.string,
        emptyKey: PropTypes.bool,
        encrypted: PropTypes.bool,
        focusedValue: PropTypes.string,
        handleAddRow: PropTypes.func,
        handleCloseButton: PropTypes.func,
        handleFocus: PropTypes.func,
        handleNewKeyBlur: PropTypes.func,
        handleNewKeyChange: PropTypes.func,
        handleNewKeyFocus: PropTypes.func,
        handleNewValueBlur: PropTypes.func,
        handleNewValueKeyDown: PropTypes.func,
        handleOnPasswordPaste: PropTypes.func,
        handleRevealPassword: PropTypes.func,
        handleSortChange: PropTypes.func,
        label: PropTypes.string,
        message: xlMessageTypeProp,
        model: PropTypes.object,
        modelKeys: PropTypes.array,
        newKey: PropTypes.string,
        newValue: PropTypes.string,
        onCleaningSearchWord: PropTypes.func,
        onKeyBlur: PropTypes.func,
        onRemoveKey: PropTypes.func,
        onSearchChanged: PropTypes.func,
        onValidityChange: PropTypes.func,
        onValueChange: PropTypes.func,
        passwordsCanBeRevealed: PropTypes.object,
        pristine: PropTypes.bool,
        required: PropTypes.bool,
        searchWord: PropTypes.string,
        showNewKeyValueRow: PropTypes.bool,
        sorting: PropTypes.object,
        updateCellState: PropTypes.func,
        valid: PropTypes.bool
    };

    static defaultProps = {encrypted: false};

    state = {typedWord: this.props.searchWord};

    componentWillReceiveProps(nextProps) {
        this.setState({typedWord: nextProps.searchWord});
    }

    onSearchChanged = (event) => {
        const newValue = event.target.value;
        this.setState({typedWord: newValue});
        this.debounceSearchChanged(newValue);
    };

    debounceSearchChanged = debounce(this.props.onSearchChanged, INPUT_DEBOUNCE_TIME);

    render() {
        const {
            autoHide,
            assignTableRef,
            assignTableWrapperRef,
            assignRef,
            description,
            disabled,
            duplicateKey,
            emptyKey,
            encrypted,
            focusedValue,
            cellState,
            handleAddRow,
            handleCloseButton,
            handleNewKeyBlur,
            handleNewKeyChange,
            handleNewKeyFocus,
            handleNewValueBlur,
            handleFocus,
            handleNewValueKeyDown,
            handleOnPasswordPaste,
            handleRevealPassword,
            handleSortChange,
            label,
            message,
            model,
            modelKeys,
            newKey,
            newValue,
            onCleaningSearchWord,
            onKeyBlur,
            onRemoveKey,
            onValueChange,
            passwordsCanBeRevealed,
            pristine,
            required,
            searchWord,
            showNewKeyValueRow,
            updateCellState,
            valid,
            sorting
        } = this.props;

        const {typedWord} = this.state;

        const inputType = getMapKeyInputType(encrypted);

        const displayKeyError = <XlReactWidgetAlertMessage
            hide={R.isNil(duplicateKey) && R.isNil(emptyKey)}
            internalState="error">
            {duplicateKey ? localeMessages.keyAlreadyInUse(duplicateKey) : localeMessages.emptyKeyErrorMessage}
        </XlReactWidgetAlertMessage>;

        const topPanel = () => <TopPanelComponent
            disabled={disabled}
            handleAddRow={handleAddRow}
            handleCleaningSearchWord={onCleaningSearchWord}
            handleSearchChanged={this.onSearchChanged}
            searchWord={typedWord}
        />;

        const hideContainer = () => autoHide !== false && R.isEmpty(modelKeys) && !showNewKeyValueRow;
        const container = () => !hideContainer() && <ScrollableContainer
            assignRef={assignRef}
            assignTableRef={assignTableRef}
            assignTableWrapperRef={assignTableWrapperRef}
            cellState={cellState}
            disabled={disabled}
            encrypted={encrypted}
            focusedValue={focusedValue}
            handleCloseButton={handleCloseButton}
            handleFocus={handleFocus}
            handleKeyBlur={onKeyBlur}
            handleNewKeyBlur={handleNewKeyBlur}
            handleNewKeyChange={handleNewKeyChange}
            handleNewKeyFocus={handleNewKeyFocus}
            handleNewValueBlur={handleNewValueBlur}
            handleNewValueKeyDown={handleNewValueKeyDown}
            handleOnPasswordPaste={handleOnPasswordPaste}
            handleRemoveKey={onRemoveKey}
            handleRevealPassword={handleRevealPassword}
            handleSortChange={handleSortChange}
            handleValueChange={onValueChange}
            hasKeyError={Boolean(duplicateKey || emptyKey)}
            inputType={inputType}
            message={message}
            model={model}
            modelKeys={modelKeys}
            newKey={newKey}
            newValue={newValue}
            passwordsCanBeRevealed={passwordsCanBeRevealed}
            pristine={pristine}
            searchWord={searchWord}
            showNewKeyValueRow={showNewKeyValueRow}
            sorting={sorting}
            updateCellState={updateCellState}
            valid={valid}
        />;

        const controlProps = {
            controlClass: 'xl-map-string-string',
            customControlClasses: validationMessageClasses(valid, message),
            description,
            disabled,
            label,
            message,
            required
        };

        return <XlReactFormItemControl {...controlProps}>
            {topPanel()}
            {displayKeyError}
            {container()}
        </XlReactFormItemControl>;
    }
}
